export declare class RIFUtil {
    /**
     * Convert JSON object to string
     *
     * @param {Object} jsonObj - JSON object.
     * @return {String} The converted string. Returns null if the conversion fails.
     */
    static json2str(jsonObj: object): string | null;
    /**
     * Convert a JSON string to an object
     *
     * @param {String} jsonObj - JSON string.
     * @return {Object} The converted object. Returns null if the conversion fails.
     */
    static str2json(jsonStr: string): object | null;
    /**
     * Get the authentication token
     *
     * @param {req} req - req object.
     * @return {string} If no authentication token is specified, returns undefined.
     */
    static getTokenByReq(req: any): string | undefined;
    /**
     * Get the authentication token
     *
     * @param {string} userId - The target user ID.
     * @return {string} Returns the authentication token. Format: tk_{userid}_{YYYYMMDDhhmm(UTC)}
     */
    static createToken(userId: string): string;
    /**
     * Convert a number to a two-digit string
     *
     * @param {number} val - The number to convert
     * @return {string} Return a two-digit string.
     */
    static getdoubleDigestNumerStr(val: number): string;
    /**
     * Obtain a user ID from an authentication token
     *
     * @param {string} token - The authentication token.
     * @return {string} Returns the user ID. Returns undefined if the authentication token is incorrect.
     */
    static getUserIdByToken(token: string): string | undefined;
    /**
     * Get a timestamp (YYYYMMDDhhmm) string from an authentication token
     *
     * @param {string} token - The authentication token.
     * @return {string} Return a timestamp (YYYYMMDDhhmm) string. Returns undefined if the authentication token is incorrect.
     */
    static getTimestampByToken(token: string): string | undefined;
    /**
     * Validating Authentication Tokens
     *
     * @param {string} token - The authentication token.
     * @return {boolean} true: correct, false: incorrect
     */
    private static isValidToken;
}
