import jwt from "jsonwebtoken";
type PayloadType = Parameters<typeof jwt.sign>[0];
/**
 * Sign a message to be sent from socketio connector (validator) to a client.
 *
 * @param privateKey - Validator private key. Only ECDSA and RSA keys are supported.
 * @param payload - Message to be encoded.
 * @param jwtAlgo - JWT algorithm to use. Must match key used (ES*** or RS***)
 * @param expirationTime - JWT expiration time
 * @returns JWT signed message that can be sent over the wire.
 */
export declare function signValidatorMessageJwt(privateKey: jwt.Secret, payload: PayloadType, jwtAlgo?: jwt.Algorithm, expirationTime?: number): string;
/**
 * Validator-side function to sign message to be sent to the client.
 * Will read the private key either as value in validator config `sslParam.keyValue`,
 * or read from filesystem under path `sslParam.key`.
 *
 * @param payload - Message to sign
 * @returns Signed message
 */
export declare function signMessageJwt(payload: object): string;
export {};
